Work toward ONOS-1451: Separate Event Key space per instance

Misc changes and cleanup:
* Added new class OnosInstanceId
* Replace (as appropriate) the string controllerId (and associated methods)
  with the new class OnosInstanceId
* Renaming: Host -> Device
  - Method getDeviceID -> getHostID
  - Changed Host Key ID prefix 'D' to 'H'
  - Few renaming of Host -> Device inside Javadoc

Change-Id: I59c20d68277ecde2f7df4e7097a4a52d5786df1b
diff --git a/src/main/java/net/onrc/onos/core/registry/IControllerRegistryService.java b/src/main/java/net/onrc/onos/core/registry/IControllerRegistryService.java
index 5af1ac1..cfc47c8 100644
--- a/src/main/java/net/onrc/onos/core/registry/IControllerRegistryService.java
+++ b/src/main/java/net/onrc/onos/core/registry/IControllerRegistryService.java
@@ -5,6 +5,7 @@
 import java.util.Map;
 
 import net.floodlightcontroller.core.module.IFloodlightService;
+import net.onrc.onos.core.util.OnosInstanceId;
 
 /**
  * A registry service that allows ONOS to register controllers and switches
@@ -81,11 +82,11 @@
     public boolean isClusterLeader();
 
     /**
      * Get the unique ID used to identify this controller in the cluster.
      *
-     * @return controller ID.
+     * @return ONOS Instance ID.
      */
-    public String getControllerId();
+    public OnosInstanceId getOnosInstanceId();
 
     /**
      * Register a controller to the ONOS cluster. Must be called before
@@ -81,11 +82,11 @@
 
     /**
-     * Get the unique ID used to identify this controller in the cluster.
+     * Gets the unique ID used to identify this ONOS instance in the cluster.
      *